%define name mageia-prepare-upgrade
%define version 2
%define release %mkrel 2

Name: %{name}
Version: %{version}
Release: %{release}
Summary: Mageia 3 Upgrade Preparation
License: GPL
Group: System/Configuration/Other
Source0: %{name}-bootloader-config
Source1: dracut-convertfs.conf
Source2: dracut-module-setup.sh
Source3: dracut-mount-var.sh
Source4: %{name}-dracut-detect-var
Source5: mageia-upgrade-dbus-skip-removal.service
Source6: README.prepare
BuildArch: noarch
Requires(post): dracut >= 17-16.1.1
Requires(post,postun): drakxtools-backend
Conflicts: mageia-release-common >= 3

%description
Prepare the system for Mageia 3 upgrade.

This package will create a new boot entry into which you must reboot at least
once in order to convert your filesystem to a state ready for Mageia 3 upgrade.

%install
rm -rf %{buildroot}
install -d -m 755 %{buildroot}%{_var}/lib/%{name}
install -D -m 755 %{SOURCE0} %{buildroot}%{_sbindir}/%{name}-bootloader-config
install -D -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/dracut.conf.d/52-%{name}.conf
install -D -m 755 %{SOURCE2} %{buildroot}%{_prefix}/lib/dracut/modules.d/98varmount/module-setup.sh
install -D -m 755 %{SOURCE3} %{buildroot}%{_prefix}/lib/dracut/modules.d/98varmount/mount-var.sh
install -D -m 755 %{SOURCE4} %{buildroot}%{_sbindir}/%{name}-dracut-detect-var
install -D -m 644 %{SOURCE5} %{buildroot}/lib/systemd/system/mageia-upgrade-dbus-skip-removal.service
install -D -m 644 %{SOURCE6} %{buildroot}%{_datadir}/doc/%{name}/README.prepare

%files
%dir %{_var}/lib/%{name}
%ghost %attr(644,root,root) %{_var}/lib/%{name}/state
%{_sysconfdir}/dracut.conf.d/52-%{name}.conf
%ghost %attr(644,root,root) %{_sysconfdir}/dracut.conf.d/53-%{name}-var.conf
%{_sbindir}/%{name}-bootloader-config
%{_sbindir}/%{name}-dracut-detect-var
%dir %{_prefix}/lib/dracut/modules.d/98varmount
%{_prefix}/lib/dracut/modules.d/98varmount/module-setup.sh
%{_prefix}/lib/dracut/modules.d/98varmount/mount-var.sh
%ghost %attr(644,root,root) %{_sysconfdir}/tmpfiles.d/%{name}.conf
/lib/systemd/system/mageia-upgrade-dbus-skip-removal.service
# (cg) Note, this is NOT marked as a doc file. If a user skips doc installation
# in their urpmi/rpm setup then we still want this file
%{_datadir}/doc/%{name}/README.prepare

%post
# Write out all temporary folders currently in /var/run to a tmpfiles config
mkdir -p %{_sysconfdir}/tmpfiles.d
find /var/run/* /var/lock/* -type d -exec stat -c "d %n 0%a %U %G -" {} \; >%{_sysconfdir}/tmpfiles.d/%{name}.conf

if [ ! -f %{_var}/lib/%{name}/state ]; then
  echo needs-preparation >%{_var}/lib/%{name}/state
fi

if [ $1 == 1 ]; then
  # Exclude dbus from urpmi updates - note preun which triggers the reverse of this (mga#9534)
  echo -e '### mageia-prepare-upgrade dbus skip start\n/^(dbus|dbus-x11|libdbus1_3|lib64dbus1_3|libdbus-devel|lib64dbus-devel|python-dbus)-1/\n### mageia-prepare-upgrade dbus skip end' >>/etc/urpmi/skip.list
fi

if [ $1 == 2 ]; then
  %{_sbindir}/bootloader-config --action remove-entry --label "Mageia 3 Upgrade Preparation" ||:
fi
%{_sbindir}/%{name}-bootloader-config --action add-entry --label "Mageia 3 Upgrade Preparation"
%{_sbindir}/%{name}-dracut-detect-var
if [ $1 == 1 ]; then
  # Just to make sure the dracut config snippet takes effect
  %{_sbindir}/bootloader-config --action rebuild-initrds
fi

%preun
if [ $1 == 0 ]; then
  # Ensure our dbus skipping is undone when the system is appropriately upgraded
  mkdir -p /etc/systemd/system/multi-user.target.wants
  cp /lib/systemd/system/mageia-upgrade-dbus-skip-removal.service /etc/systemd/system/mageia-upgrade-dbus-skip-removal.service
  ln -s ../mageia-upgrade-dbus-skip-removal.service /etc/systemd/system/multi-user.target.wants/mageia-upgrade-dbus-skip-removal.service
fi

%postun
if [ $1 == 0 ]; then
  %{_sbindir}/bootloader-config --action remove-entry --label "Mageia 3 Upgrade Preparation"
  # The following should be removed by ghosting,.. but be super sure.
  rm -f %{_sysconfdir}/dracut.conf.d/53-%{name}-var.conf
  rm -f %{_sysconfdir}/tmpfiles.d/%{name}.conf
  rm -f %{_var}/lib/%{name}/state
  rmdir %{_var}/lib/%{name} 2>/dev/null ||:
fi


%changelog

* Sun May 19 2013 colin <colin> 2-2.mga2
+ Revision: 413565
- Don't require newer urpmi, this require should go in the mgaonline package.
- Require the new urpmi with the priority-updates-in-single-transaction fix
- Kill manual line wrapping as it messes up the display.
- Add a more robust way to preserve vga bootloader setting. mga#10053
- Revert vga preservation patch as it breaks lilo (mga#10053)
- Mask an error on uninstall
- Fix ghost file perms
- Bump required dracut version
- Add preparation state and README.prepare (mga#9744)
- Use multi-user.target over sysinit.target as the former results in ordering cycles.
- Add python-dbus to the exclusions as it pulls in dbus-devel
- Fix the dbus skip+removal script.
- Install the correct source
- Fix filelist
- Fix dbus upgrade exclusion list to be more selective.
- Add a workaround to disable dbus upgrades on live systems and remove after upgrade completes (mga#9534)
- Add explicity file attribs for ghost file
- Ensure we remove the dracut config on uninstall (don't rely on ghosting)
- Preserve vga mode in the kernel command line.
- Ensure all folders under /var/{run,lock} are migrated to a tmpfiles config.
- Own the dracut module dir so it is removed on uninstall.
- Correct copy+paste error on detecting /var
- Set attr on ghosted file
- Add support for /var on a separate partition
- Fix %%post script for rebuilding initrds
- Refactor to avoid specific kernel version requirement.
- Fix group
- Initial version of upgrade package

